NAME
CPAN::MetaCurator - Manage the cpan.metacurator.sqlite database
How to convert a Perl.Wiki.html into a jsTree
Note: My web host and I use case-sensitive file systems.
Prepare wikis
Export Perl.Wiki.html
Rebuild Perl Wiki Tree
Patch ~/savage.net.au/index.html
Upload
Machine-Readable Change Log
The file Changes was converted into Changelog.ini by Module::Metadata::Changes.
Version Numbers
Version numbers < 1.00 represent development versions. From 1.00 up, they are production versions.
Repository
https://github.com/ronsavage/CPAN-MetaCurator
Support
Email the author, or log a bug on RT:
https://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-MetaCurator.
Author
Current maintainer: Ron Savage <ron@savage.net.au>.
My homepage: https://savage.net.au/.
License
Perl 5.
Copyright
Australian copyright (c) 2025, Ron Savage.
All Programs of mine are 'OSI Certified Open Source Software';
you can redistribute them and/or modify them under the terms of
The Perl License, a copy of which is available at:
http://dev.perl.org/licenses/
10 POD Errors
The following errors were encountered while parsing the POD:
- Around line 21:
=over should be: '=over' or '=over positive_number'
- Around line 29:
You forgot a '=back' before '=head2'
- Around line 31:
=over should be: '=over' or '=over positive_number'
- Around line 38:
You forgot a '=back' before '=head2'
- Around line 40:
=over should be: '=over' or '=over positive_number'
- Around line 48:
You forgot a '=back' before '=head2'
- Around line 50:
=over should be: '=over' or '=over positive_number'
- Around line 58:
You forgot a '=back' before '=head2'
- Around line 60:
=over should be: '=over' or '=over positive_number'
- Around line 68:
You forgot a '=back' before '=head1'